//-*-c++-*-
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "tulip/Layout.h"
#include "tulip/TemplateFactory.h"
#include "tulip/SuperGraph.h"
#include "tulip/PluginContext.h"
#include "tulip/LayoutProxy.h"

Layout::Layout (const PropertyContext & context):Property<PointType , LineType>(context) {
  layoutProxy=(LayoutProxy *)context.propertyProxy;
}

Layout::~Layout() {}

